sage_numerical_backends_cplex: Cplex backend for Sage MixedIntegerLinearProgram
===============================================================================

Description
-----------

Cplex backend for Sage MixedIntegerLinearProgram

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/passagemath-cplex/

